# Manim Studio

![Manim Studio](/logo.png)

Manim Studio is a Manim plugin to live-preview animations rendered with Cairo, and also it's useful for many other things!

## Features
- [x] Live preview for Cairo animations.
- [x] Saving and loading snippets.
- [x] Saving full scene snipets.
- [ ] Create slides with Manim Studio.
- [ ] Basic editing for Manim videos.
- [ ] Direct livestreaming with OBS.
- [ ] Snippet gallery.

## Requirements
- Installed Python 3.
- Installed Manim.
- Installed PyQt6.
- Installed Git.

## Steps to use
1. Once you have installed all the requirements, you must clone this repository.
   
   ```git clone https://github.com/MathItYT/manim-studio)https://github.com/MathItYT/manim-studio```
3. To use Manim Studio, simply go to manim-studio folder and run `main.py`.
   
   ```python main.py```
5. Use the program! We still don't have a documentation, but there will be one in the future!
